@@ -72,7 +72,7 @@ The atoms in a ``Residue`` or a ``ResidueType`` can be obtained by their names.
 
 """
 
-__version__ = "1.2.6.12.8"
+__version__ = "1.3.1"
 
 import os
 import time
@@ -84,10 +84,10 @@ import numpy as np
 
 from . import assign
 from .assign import Assign, get_assignment_from_pdb, get_assignment_from_mol2, get_assignment_from_pubchem, \
-    get_assignment_from_residuetype, get_assignment_from_xyz
+    get_assignment_from_residuetype, get_assignment_from_xyz, get_assignment_from_smiles
 from .helper import GlobalSetting, Type, AbstractMolecule, ResidueType, Entity, Atom, Residue, ResidueLink, Molecule, \
     AtomType, set_global_alternative_names, generate_new_pairwise_force_type, generate_new_bonded_force_type, source, \
-    Xprint
+    Xprint, debug
 from .load import load_ffitp, load_mol2, load_rst7, load_frcmod, load_pdb, load_parmdat, load_coordinate
 from .build import save_mol2, save_pdb, save_sponge_input, save_gro, build_bonded_force, get_mindsponge_system_energy
 from .process import impose_bond, impose_angle, impose_dihedral, add_solvent_box, h_mass_repartition, solvent_replace, \
