@@ -9,6 +9,7 @@ import os
 import time
 import stat
 import copy
+import logging
 from types import MethodType, FunctionType
 from functools import partial, partialmethod, wraps, update_wrapper
 from collections import OrderedDict
@@ -57,8 +58,14 @@ when the key is not found. **New From 1.2.6.7**
             raise KeyError(self.not_found_message.format(key))
         raise KeyError(f"{key}")
 
-
+#pylint: disable=unused-argument
 class ReasonedBool(int):
+    """
+        This **class** is a boolean value with a reason
+
+        :param value: True or False
+        :param reason: the reason why the boolean value is given
+    """
     _repr = ["False", "True"]
     def __new__(cls, value, reason=None):
         return int.__new__(cls, bool(value))
@@ -66,6 +73,9 @@ class ReasonedBool(int):
     def __init__(self, value, reason=None):
         self.reason = reason
 
+    def __str__(self):
+        return self.__repr__()
+
     def __repr__(self):
         if self.reason:
             return self._repr[self] + f" (Reason: {self.reason})"
@@ -94,20 +104,28 @@ def xopen(filename, flag, mode=None):
     return fo
 
 
-def xprint(*args, **kwargs):
+def xprint(to_print, verbose=logging.INFO):
     """
-    This **function** is used to print information according to the verbose level in GlobalSetting
+    This **function** is used to print some contents according to the verbose level in GlobalSetting
 
-    :param args, kwargs except verbose: the arguments to print
+    :param to_print: the contents to print
     :param verbose: only print when the verbose level is not less than this value
     :return: None
     """
-    if "verbose" in kwargs:
-        verbose = kwargs.pop("verbose")
+    if verbose in ("INFO", "DEBUG", "WARNING", "ERROR", "CRITICAL"):
+        verbose = getattr(logging, verbose)
+    GlobalSetting.logger.log(verbose, to_print)
+
+
+def debug(mode=True):
+    """
+    This **function** sets the mode to debug or not
+    :param mode: the value to set the debug mode
+    """
+    if mode:
+        GlobalSetting.logger.setLevel(logging.DEBUG)
     else:
-        verbose = 0
-    if GlobalSetting.verbose >= verbose:
-        print(*args, **kwargs)
+        GlobalSetting.logger.setLevel(logging.INFO)
 
 
 class _GlobalSetting():
@@ -118,10 +136,6 @@ class _GlobalSetting():
     Do not initialize an instance yourself.
     """
     def __init__(self):
-        set_attribute_alternative_names(self)
-        # 打印信息的详细程度
-        self.verbose = 0
-        """the global verbose level"""
         # 是否将分子移到中心
         self.nocenter = False
         """move the molecule to the center of the box when building"""
@@ -143,6 +157,22 @@ class _GlobalSetting():
                                       "angle": {"degree": np.pi, "rad": 180}
                                       })
         setattr(self, "PDBResidueNameMap", {"head": Xdict(), "tail": Xdict(), "save": Xdict()})
+        # 消息
+        logger = logging.getLogger("Xponge")
+        console_handler = logging.StreamHandler()
+        debug_formatter = logging.Formatter('[%(name)s | %(levelname)s] %(message)s')
+        console_handler.setFormatter(debug_formatter)
+        console_handler.addFilter(lambda record: record.levelno != logging.INFO)
+
+        console2_handler = logging.StreamHandler()
+        info_formatter = logging.Formatter('%(message)s')
+        console2_handler.setFormatter(info_formatter)
+        console2_handler.addFilter(lambda record: record.levelno == logging.INFO)
+
+        logger.setLevel(logging.INFO)
+        logger.addHandler(console_handler)
+        logger.addHandler(console2_handler)
+        self.logger = logger
 
     @staticmethod
     def set_unit_transfer_function(sometype):
@@ -188,6 +218,13 @@ class _GlobalSetting():
 
         return wrapper
 
+    @property
+    def verbose(self):
+        """
+            the gloabl verbose level
+        """
+        return self.logger.level
+
     def add_pdb_residue_name_mapping(self, place, pdb_name, real_name):
         """
         This **function** is used to add the residue name mapping to the property ``PDBResidueNameMap``
@@ -222,6 +259,7 @@ class _GlobalSetting():
         for typename in types:
             self.BondedForces.append(self.BondedForcesMap[typename])
 
+set_classmethod_alternative_names(_GlobalSetting)
 
 globals()["GlobalSetting"] = _GlobalSetting()
 
@@ -261,7 +299,7 @@ class Type(ABC):
         return hash(repr(self))
 
     def __getattribute__(self, attr):
-        if attr != "contents" and attr in self.contents.keys():
+        if attr != "contents" and hasattr(self, "contents") and attr in self.contents.keys():
             return self.contents[attr]
         return super().__getattribute__(attr)
 
@@ -529,11 +567,6 @@ class AtomType(Type):
     _types_different_name = Xdict(not_found_message="Atom Type {} not found. Did you import the proper force field?")
 
 
-set_classmethod_alternative_names(AtomType)
-
-AtomType.New_From_String("name\nUNKNOWN")
-
-
 class ResidueType(Type):
     """
     This **class** is a subclass of Type, for residue types
@@ -574,10 +607,8 @@ class ResidueType(Type):
         """a dict mapping the atom to \
  another dict which mapping the connecting type to the name of the connected atom"""
 
-        set_attribute_alternative_names(self)
-
     def __getattribute__(self, attr):
-        if attr not in ("_name2atom", "contents") and attr in self._name2atom.keys():
+        if attr not in ("_name2atom", "contents") and hasattr(self, "_name2atom") and attr in self._name2atom.keys():
             return self._name2atom[attr]
         if getattr(AtomType, "_parameters").get(attr, None) == float:
             return np.sum([getattr(atom, attr) for atom in self.atoms])
@@ -829,7 +860,6 @@ None to use the charge sum of the unomitted atoms
 
         return new_restype
 
-
 class Entity(ABC):
     """
     This **class** is the abstract class of the entities (atoms, bonded forces, residues and so on).
@@ -858,7 +888,7 @@ class Entity(ABC):
         return hash(repr(self))
 
     def __getattribute__(self, attr):
-        if attr != "contents" and attr in self.contents.keys():
+        if attr != "contents" and hasattr(self, "contents") and attr in self.contents.keys():
             return self.contents[attr]
         return super().__getattribute__(attr)
 
@@ -891,6 +921,10 @@ class Entity(ABC):
         unit_transfer(self)
 
 
+def not_found_method(key):
+    return {}
+
+
 class Atom(Entity):
     """
     This **class** is a subclass of Entity, for atoms
@@ -919,14 +953,13 @@ class Atom(Entity):
 
         # 成键信息
         self.linked_atoms = Xdict({i + 1: set() for i in range(1, GlobalSetting.farthest_bonded_force)},
-                                  not_found_method=lambda key:set())
+                                  not_found_method=not_found_method)
         """a dict mapping the type and the atoms linked"""
         self.linked_atoms["extra_excluded_atoms"] = set()
 
         # 复制信息
         self.copied = Xdict()
         """a dict to find who is a copy of the atom"""
-        set_attribute_alternative_names(self)
 
     @property
     def extra_excluded_atoms(self):
@@ -983,9 +1016,6 @@ class Atom(Entity):
             self.Extra_Exclude_Atom(atom)
 
 
-set_classmethod_alternative_names(Atom)
-
-
 class Residue(Entity):
     """
     This **class** is a subclass of Entity, for residues
@@ -1023,10 +1053,8 @@ class Residue(Entity):
                 for aton in atom.extra_excluded_atoms:
                     atom.copied[forcopy].Extra_Exclude_Atom(aton.copied[forcopy])
 
-        set_attribute_alternative_names(self)
-
     def __getattribute__(self, attr):
-        if attr not in ("_name2atom", "contents") and attr in self._name2atom.keys():
+        if attr not in ("_name2atom", "contents") and hasattr(self, "_name2atom") and attr in self._name2atom.keys():
             return self._name2atom[attr]
         if getattr(AtomType, "_parameters").get(attr, None) == float:
             return np.sum([getattr(atom, attr) for atom in self.atoms])
@@ -1232,9 +1260,6 @@ class Residue(Entity):
         return new_residue
 
 
-set_classmethod_alternative_names(Residue)
-
-
 class ResidueLink:
     """
     This **class** is a class for the link between residues
@@ -1254,7 +1279,6 @@ class ResidueLink:
         """the bonded forces after building"""
         self.tohash = ResidueLink.get_hash(atom1, atom2, "atom")
         self.residue_tohash = ResidueLink.get_hash(atom1.residue, atom2.residue, "residue")
-        set_attribute_alternative_names(self)
 
     def __repr__(self):
         return "Entity of ResidueLink: " + repr(self.atom1) + "-" + repr(self.atom2)
@@ -1304,7 +1328,7 @@ class ResidueLink:
         """
         if self.atom1.copied[forcopy] and self.atom2.copied[forcopy]:
             return ResidueLink(self.atom1.copied[forcopy], self.atom2.copied[forcopy])
-        raise Exception("Not Right forcopy")
+        raise ValueError("Not Right forcopy")
 
 
 class Molecule():
@@ -1357,8 +1381,6 @@ class Molecule():
                 new_residue.Add_Atom(i)
             self.Add_Residue(new_residue)
 
-        set_attribute_alternative_names(self)
-
     def __repr__(self):
         return "Entity of Molecule: " + self.name
 
@@ -1651,12 +1673,14 @@ If None, the information will be deleted between start and end
         """
         self._missing_residues.clear()
 
-    def add_missing_residues(self):
+    def add_missing_residues(self, add_head=False, add_tail=False):
         """
         This **function** is used to add the missing residues according to the information of the missing residues.
         The information of the missing residues may be set by `set_missing_residues_info` or `load_pdb`
         **New From 1.2.6.7**
 
+        :param add_head: whether to add the missing residues at the head of the chain
+        :param add_tail: whether to add the missing residues at the tail of the chain
         :return: None
         """
         for (start, end), to_insert in self._missing_residues.items():
@@ -1670,6 +1694,8 @@ If None, the information will be deleted between start and end
                 loop_direction = self.find_spacious_direction(start_position)
                 self.del_residue_link(tail, link_to_tail)
             elif start is not None and end is None:
+                if not add_tail:
+                    continue
                 ref_res = start
                 start.unterminal()
                 tail = start.name2atom(start.type.tail)
@@ -1684,11 +1710,13 @@ If None, the information will be deleted between start and end
                 end_position += start_position
                 loop_direction = np.zeros_like(start_position)
             elif start is None and end is not None:
+                if not add_head:
+                    continue
                 tail = None
                 ref_res = end
                 end.unterminal()
                 link_to_tail = end.name2atom(end.type.head)
-                insert_index = 0
+                insert_index = self.residues.index(end)
                 end_position = np.array([getattr(link_to_tail, i) for i in "xyz"])
                 start_position = self.find_spacious_direction(end_position)
                 norm = np.linalg.norm(start_position)
@@ -1965,8 +1993,6 @@ def _link_residue_process_coordinate(molecule, atom1, atom2):
         atom.z = crd[i][2]
 
 
-set_classmethod_alternative_names(Molecule)
-set_classmethod_alternative_names(ResidueLink)
 Entity.register(ResidueLink)
 Entity.register(Molecule)
 AbstractMolecule.register(Residue)
@@ -1992,8 +2018,9 @@ def _add(self, other, deepcopy, link):
         res_b = other_molecule.residues[0]
         new_molecule.residues += other_molecule.residues
         new_molecule.residue_links |= other_molecule.residue_links
-        getattr(new_molecule, "_residue_links_map")["atom"].update(getattr(other_molecule, "_residue_links_map")["atom"])
-        getattr(new_molecule, "_residue_links_map")["residue"].update(getattr(other_molecule, "_residue_links_map")["residue"])
+        #pylint: disable=protected-access
+        new_molecule._residue_links_map["atom"].update(other_molecule._residue_links_map["atom"])
+        new_molecule._residue_links_map["residue"].update(other_molecule._residue_links_map["residue"])
         if link and res_a and res_a.type.tail and res_b.type.head:
             atom1 = res_a.name2atom(res_a.type.tail)
             atom2 = res_b.name2atom(res_b.type.head)
@@ -2112,6 +2139,7 @@ def generate_new_bonded_force_type(type_name, atoms, properties, is_compulsory,
         def same_force(cls, atom_list):
             """
             This **function** receives a list of atoms and output all the same force permutations for the list
+
             :param atom_list:
             :return:
             """
@@ -2124,7 +2152,9 @@ def generate_new_bonded_force_type(type_name, atoms, properties, is_compulsory,
 
         @classmethod
         def set_same_force_function(cls, func):
-            cls.Same_Force = classmethod(func)
+            update_wrapper(func, cls.same_force)
+            cls.same_force = classmethod(func)
+            set_attribute_alternative_name(cls, cls.same_force)
 
         @classmethod
         def type_name_getter(cls, func):
@@ -2195,3 +2225,4 @@ def generate_new_pairwise_force_type(type_name, properties):
     return PairwiseForceType
 
 set_global_alternative_names(True)
+AtomType.New_From_String("name\nUNKNOWN")
