@@ -403,10 +403,12 @@ def _pdb_find_missing_residues(mol, sequences, chain, residue_type_map):
                 name_index_to_mol_index[i - pdb_index[0]] = pdb_index_to_mol_index[i]
             offset = 0
             for offset in range(len(sequence) - len(names_with_none) + 1):
-                if all(b in (a, None) for a, b in zip(sequence[offset:], names_with_none)):
+                if all(b in (a, None) or
+                       (a == "HIS" and b in (None, "HID", "HIE", "HIP"))
+                       for a, b in zip(sequence[offset:], names_with_none)):
                     break
             if offset:
-                mol.set_missing_residues_info(None, name_index_to_mol_index[offset], sequence[:offset])
+                mol.set_missing_residues_info(None, name_index_to_mol_index[0], sequence[:offset])
             tail_offset = len(sequence) - offset - len(names_with_none)
             if tail_offset:
                 tail_index = name_index_to_mol_index[len(names_with_none) - 1]
@@ -967,7 +969,7 @@ class GromacsTopologyIterator():
         elif words[0] == "#undef":
             self.defined_macros.pop(words[1])
         elif words[0] == "#error":
-            raise Exception(line)
+            raise AssertionError(line)
         line = next(self)
         return line
 
