@@ -6,7 +6,7 @@ from abc import ABC, abstractmethod
 
 import numpy as np
 from .helper import get_rotate_matrix, ResidueType, Molecule, Residue, set_global_alternative_names, Xdict, \
-    GlobalSetting, set_attribute_alternative_names, Xopen, Xprint
+    GlobalSetting, Xopen, Xprint
 from .build import save_sponge_input
 from .load import load_coordinate
 from .forcefield.special.min import save_min_bonded_parameters, do_not_save_min_bonded_parameters
@@ -171,12 +171,12 @@ def add_solvent_box(molecule, solvent, distance, tolerance=3):
     if isinstance(distance, (float, int)):
         distance = [distance] * 6
     elif not isinstance(distance, list):
-        raise Exception("parameter distance should be a list, an int or a float")
+        raise TypeError("parameter distance should be a list, an int or a float")
 
     if len(distance) == 3:
         distance = distance + distance
     elif len(distance) != 6:
-        raise Exception("the length of parameter distance should be 3 or 6")
+        raise TypeError("the length of parameter distance should be 3 or 6")
 
     if isinstance(molecule, ResidueType):
         new_molecule = Molecule(molecule.name)
@@ -372,8 +372,7 @@ def get_peptide_from_sequence(sequence, charged_terminal=True):
     return toret
 
 
-def optimize(mol, step=2000, only_bad_coordinate=True, dt=1e-8, force_limit=50,
-             epoch_limit=10, pbc=True, extra_commands=None):
+def optimize(mol, step=2000, only_bad_coordinate=True, dt=1e-8, pbc=True, extra_commands=None):
     """
     This **function** is used to optimize the structure of the Molecule instance
 
@@ -381,22 +380,19 @@ def optimize(mol, step=2000, only_bad_coordinate=True, dt=1e-8, force_limit=50,
     :param step: the limited step for each epoch for minimization, 2000 for default
     :param only_bad_coordinate: whether to optimize all the atoms or the atoms whose coordinates are bad
     :param dt: the start dt for minimization
-    :param force_limit: the minimization will stop if the largest difference in unit of `kcal/mol/A` \
-between forces in two steps is not more than this value.
-    :param epoch_limit: the minimization will stop if the epoch is not less than this value.
     :param pbc: whether to use the periodic box condition
     :param extra_commands: a dict, with the extra commands to pass to the MD engine
-    :return: 0 for reaching the force limitation, 1 for reaching the epoch limitation
+    :return: None
     """
     from tempfile import TemporaryDirectory
-    Xprint("Optimizing", verbose=0)
+    Xprint("Optimizing")
     with TemporaryDirectory() as tempdir:
         temp_prefix = os.path.join(tempdir, "temp")
         temp_out = os.path.join(tempdir, "min")
-        Xprint("    Parametering", verbose=0)
+        Xprint("    Parametering")
         save_min_bonded_parameters()
         if not pbc:
-            box_length_backup = mol.box_length
+            box_length_backup = mol.box_length if hasattr(mol, "box_length") else None
             mol.box_length = [999, 999, 999]
         save_sponge_input(mol, temp_prefix)
         if not pbc:
@@ -412,6 +408,7 @@ box = {temp_prefix}.box
 mdout = {temp_out}.out
 mdinfo = {temp_out}.info
 mode = minimization
+minimization_dynamic_dt = 1
 step_limit = {step}
 write_information_interval = {step}
 molecule_map_output  = 1
@@ -426,40 +423,19 @@ molecule_map_output  = 1
             all_to_use = f"SPONGE -mdin {temp_mdin_name} "
         else:
             all_to_use = f"SPONGE_NOPBC -mdin {temp_mdin_name} "
-        if force_limit > 0:
-            all_to_use += f"-frc {temp_out}.frc "
         if only_bad_coordinate:
             all_to_use += f"-mass_in_file {temp_prefix + '_fake_mass.txt'} "
-        if GlobalSetting.verbose < 2:
+        if GlobalSetting.verbose > 10:
             print_to = f" > {os.devnull}"
         else:
             print_to = ""
-        Xprint("    Running", verbose=0)
-        run(all_to_use + f"-dt {dt} {print_to}")
-        all_to_use += f"-coordinate_in_file {temp_out+'_coordinate.txt'} "
-        start_dt = dt
-        if force_limit > 0:
-            frc = np.fromfile(f"{temp_out}.frc", dtype=np.float32).reshape(-1, 3)
-            frc = np.linalg.norm(frc, axis=1)
-            last_frc = np.zeros_like(frc)
-            epoch = 0
-            Xprint("Epoch    Max Force Difference    Force Limit    Epoch Limit", verbose=0)
-            while not np.all(np.abs(frc - last_frc) < force_limit) and epoch < epoch_limit:
-                epoch += 1
-                dt = np.max((np.min((1e-3, np.sqrt(1e-4 / np.max(frc)))), start_dt))
-                run(all_to_use + f"-dt {dt} {print_to}")
-                last_frc = frc
-                frc = np.fromfile(f"{temp_out}.frc", dtype=np.float32).reshape(-1, 3)
-                frc = np.linalg.norm(frc, axis=1)
-                Xprint("{0:5d}{1:>24.4f}{2:15.4f}{3:15d}".format(epoch,
-                                                                 np.max(np.abs(frc - last_frc)),
-                                                                 force_limit,
-                                                                 epoch_limit), verbose=0)
-        load_coordinate(temp_out+'_coordinate.txt', mol)
-        Xprint("Optimization Finished", verbose=0)
-        if np.all(np.abs(frc - last_frc) < force_limit):
-            return 0
-        return 1
+        Xprint("    Running")
+        out = run(all_to_use + f"-dt {dt} {print_to}")
+        if out == 0:
+            load_coordinate(temp_out+'_coordinate.txt', mol)
+        else:
+            Xprint("The optimization failed", "ERROR")
+        Xprint("Optimization Finished")
 
 
 class Region(ABC):
@@ -470,7 +446,6 @@ class Region(ABC):
     def __init__(self):
         self.side = "in"
         self._side = True
-        set_attribute_alternative_names(self)
 
     @abstractmethod
     def __contains__(self, item):
@@ -492,7 +467,6 @@ class Region(ABC):
             raise ValueError("side should be 'in' or 'out'")
 
 
-
 class IntersectRegion:
     """
     This **class** is used to get the interset region of some regions
@@ -721,8 +695,6 @@ class Lattice:
             style_name = style.split(":")[1].strip()
             Lattice.styles[style_name] = self
 
-        set_attribute_alternative_names(self)
-
     @staticmethod
     def _judge_region(x1, y1, z1, x2, y2, z2, region, mol, basis_mol, res_len):
         """
